# Kraken CI

![Release Version](https://img.shields.io/github/v/release/Kraken-CI/kraken)
![Release Date](https://img.shields.io/github/release-date/Kraken-CI/kraken)

![Kraken Build](https://lab.kraken.ci/bk/branch-badge/2)
![Kraken Tests](https://lab.kraken.ci/bk/branch-badge/2/tests)
![Kraken Issues](https://lab.kraken.ci/bk/branch-badge/2/issues)

[![Codacy Badge](https://app.codacy.com/project/badge/Grade/be770bd29e374ece9e6f2782a1de99fc)](https://www.codacy.com/gh/Kraken-CI/kraken/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=Kraken-CI/kraken&amp;utm_campaign=Badge_Grade)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/Kraken-CI/kraken.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/Kraken-CI/kraken/context:python)
[![Language grade: JavaScript](https://img.shields.io/lgtm/grade/javascript/g/Kraken-CI/kraken.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/Kraken-CI/kraken/context:javascript)
[![Total alerts](https://img.shields.io/lgtm/alerts/g/Kraken-CI/kraken.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/Kraken-CI/kraken/alerts/)
[![codebeat badge](https://codebeat.co/badges/556ac028-2390-4093-839e-a509f5678cf1)](https://codebeat.co/projects/github-com-kraken-ci-kraken-master)

[![CII Best Practices](https://bestpractices.coreinfrastructure.org/projects/4758/badge)](https://bestpractices.coreinfrastructure.org/projects/4758)
[![Artifact Hub](https://img.shields.io/endpoint?url=https://artifacthub.io/badge/repository/kraken-ci)](https://artifacthub.io/packages/search?repo=kraken-ci)


<!-- ABOUT THE PROJECT -->
## About Kraken CI

![Kraken CI Results Page](https://kraken.ci/img/slide-branch-results.png)

Kraken CI is a modern, open-source, on-premise CI/CD system
that is highly scalable and focused on testing.

More information can be found on https://kraken.ci


<!-- GETTING STARTED -->
## Getting Started

Quick start guide is here: https://kraken.ci/docs/quick-start

Full installation manual: https://kraken.ci/docs/installation

And here is developers guide: https://kraken.ci/docs/dev-guide


<!-- USAGE EXAMPLES -->
## Usage

Guides can be found here: https://kraken.ci/docs/guide-intro

Demo site is available here: https://lab.kraken.ci/


<!-- ROADMAP -->
## Roadmap

See the [open issues](https://github.com/kraken-ci/kraken/issues) for a list of proposed features (and known issues).


<!-- CONTRIBUTING -->
## Contributing

Contributions are what make the open source community such an amazing place to be learn, inspire, and create. Any contributions you make are **greatly appreciated**.

Details on https://kraken.ci/docs/contrib-kraken


<!-- LICENSE -->
## License

Distributed under the Apache 2.0 License. See `LICENSE` for more information.


<!-- CONTACT -->
## Contact

Michal Nowikowski - godfryd@gmail.com

Project Link: [https://kraken.ci](https://kraken.ci)
